@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2004-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2004-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you did not
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -207,6 +207,8 @@ class Trean_Bookmarks
         /* Untag */
         $tagger = $GLOBALS['injector']->getInstance('Trean_Tagger');
         $tagger->replaceTags((string)$bookmark->id, array(), $GLOBALS['registry']->getAuth(), 'bookmark');
+        $GLOBALS['injector']->getInstance('Content_Objects_Mapper')
+            ->delete($bookmark->id, 'bookmark');
 
         /* @TODO delete from content index? */
         //$indexer->index('horde-user-' . $this->_userId, 'trean-bookmark', $this->_bookmarkId, json_encode(array(
@@ -238,6 +240,7 @@ class Trean_Bookmarks
         $tagger = $GLOBALS['injector']->getInstance('Trean_Tagger');
         $charset = $GLOBALS['trean_db']->getOption('charset');
         foreach ($bookmarks as $bookmark) {
+            $cvBookmarks = array();
             foreach ($bookmark as $key => $value) {
                 if (!empty($value) && !is_numeric($value)) {
                     $cvBookmarks[$key] = Horde_String::convertCharset($value, $charset, 'UTF-8');
